@@ -11,17 +11,17 @@ use DBIx::Custom::QueryBuilder::TagProcessors;
 
 __PACKAGE__->dual_attr('tag_processors', default => sub { {} }, inherit => 'hash_copy');
 __PACKAGE__->register_tag_processor(
-    '?'      => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_placeholder_tag,
-    '='      => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_equal_tag,
-    '<>'     => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_not_equal_tag,
-    '>'      => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_greater_than_tag,
-    '<'      => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_lower_than_tag,
-    '>='     => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_greater_than_equal_tag,
-    '<='     => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_lower_than_equal_tag,
-    'like'   => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_like_tag,
-    'in'     => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_in_tag,
-    'insert' => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_insert_tag,
-    'update' => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_update_tag
+    '?'     => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_placeholder_tag,
+    '='     => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_equal_tag,
+    '<>'    => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_not_equal_tag,
+    '>'     => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_greater_than_tag,
+    '<'     => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_lower_than_tag,
+    '>='    => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_greater_than_equal_tag,
+    '<='    => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_lower_than_equal_tag,
+    'like'  => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_like_tag,
+    'in'    => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_in_tag,
+    'insert_param' => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_insert_param_tag,
+    'update_param' => \&DBIx::Custom::QueryBuilder::TagProcessors::expand_update_param_tag
 );
 
 __PACKAGE__->attr(tag_start => '{');
@@ -324,12 +324,12 @@ In tag.
 
 =head2 C<insert>
 
-Insert tag.
+Insert parameter tag.
 
-    {insert NAME1 NAME2}   ->   (NAME1, NAME2) values (?, ?)
+    {insert_param NAME1 NAME2}   ->   (NAME1, NAME2) values (?, ?)
 
 =head2 C<update>
 
-Updata tag.
+Updata parameter tag.
 
-    {update NAME1 NAME2}   ->   set NAME1 = ?, NAME2 = ?
+    {update_param NAME1 NAME2}   ->   set NAME1 = ?, NAME2 = ?
